commands

package
v0.0.0-...-c5aa536 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 28, 2025 License: MIT Imports: 15 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Browse

func Browse()

Browse shows all tracked files in an interactive browser

func Daemon

func Daemon(args []string)

Daemon runs the daemon in foreground mode with TUI

func Dashboard

func Dashboard()

Dashboard displays the live daemon status

func Install

func Install()

Install generates system service files for daemon auto-start

func ParseLogFile

func ParseLogFile(logPath string, maxLines int) ([]string, time.Time, int)

ParseLogFile reads the last N lines from the log file and extracts sync info

func Start

func Start(args []string)

Start starts the daemon in background mode

func Status

func Status()

Status displays the current sync status

func Stop

func Stop()

Stop stops the running daemon

func Sync

func Sync(args []string)

Sync performs a one-shot sync operation

func Uninstall

func Uninstall()

Uninstall removes system service files

Types

This section is empty.

Jump to